@@ -1,9 +1,10 @@
 //! Manages build-tool probes that are used to recognize projects.
 
-use camino::Utf8Path;
+use std::path::Path;
+
 use tracing::debug;
 
-use crate::build_tools::{cargo, elm, npm, BuildTool, BuildToolProbe};
+use crate::build_tools::{cargo, elm, mix, npm, BuildTool, BuildToolProbe};
 
 pub struct BuildToolManager {
     probes: Vec<Box<dyn BuildToolProbe>>,
@@ -17,12 +18,12 @@ impl Default for BuildToolManager {
 
         cargo::register(&mut build_tool_manager);
         elm::register(&mut build_tool_manager);
+        mix::register(&mut build_tool_manager);
         npm::register(&mut build_tool_manager);
 
         // TODO: Activate those as soon as the tests are there:
         // gradle::register(&mut build_tool_manager);
         // maven::register(&mut build_tool_manager);
-        // mix::register(&mut build_tool_manager);
 
         build_tool_manager
     }
@@ -59,7 +60,7 @@ impl BuildToolManager {
     }
 
     /// Returns all build tools that apply to a given location.
-    pub fn probe(&self, path: &Utf8Path) -> Vec<Box<dyn BuildTool>> {
+    pub fn probe(&self, path: &Path) -> Vec<Box<dyn BuildTool>> {
         self.probes
             .iter()
             .filter_map(|probe| probe.probe(path))
