@@ -1,8 +1,10 @@
 use super::{BuildStatus, BuildTool, BuildToolProbe};
 use crate::{build_tool_manager::BuildToolManager, fs::dir_size};
 use anyhow::{bail, Context};
-use camino::{Utf8Path, Utf8PathBuf};
-use std::process::Command;
+use std::{
+    path::{Path, PathBuf},
+    process::Command,
+};
 
 pub fn register(manager: &mut BuildToolManager) {
     let probe = Box::new(MixProbe {});
@@ -13,7 +15,7 @@ pub fn register(manager: &mut BuildToolManager) {
 pub struct MixProbe;
 
 impl BuildToolProbe for MixProbe {
-    fn probe(&self, path: &Utf8Path) -> Option<Box<dyn BuildTool>> {
+    fn probe(&self, path: &Path) -> Option<Box<dyn BuildTool>> {
         if path.join("mix.exs").is_file() {
             Some(Box::new(Mix {
                 path: path.to_owned(),
@@ -32,7 +34,7 @@ impl BuildToolProbe for MixProbe {
 
 #[derive(Debug)]
 pub struct Mix {
-    path: Utf8PathBuf,
+    path: PathBuf,
 }
 
 impl BuildTool for Mix {
@@ -40,17 +42,21 @@ impl BuildTool for Mix {
         let mut cmd = Command::new("mix");
         let cmd = cmd.args(["clean", "--deps"]).current_dir(&self.path);
         if dry_run {
-            println!("{}: {:?}", self.path, cmd);
+            println!("{}: {:?}", self.path.display(), cmd);
         } else {
             let status = cmd.status().with_context(|| {
-                format!("Failed to execute {:?} for project at {}", cmd, self.path)
+                format!(
+                    "Failed to execute {:?} for project at {}",
+                    cmd,
+                    self.path.display()
+                )
             })?;
             if !status.success() {
                 bail!(
                     "Unexpected exit code {} for {:?} for project at {}",
                     status,
                     cmd,
-                    self.path
+                    self.path.display()
                 );
             }
         }
@@ -61,13 +67,23 @@ impl BuildTool for Mix {
         let build_dir = self.path.join("_build");
         let deps_dir = self.path.join("deps");
         let status = if build_dir.exists() || deps_dir.exists() {
-            let freeable_bytes = dir_size(build_dir.as_ref()) + dir_size(deps_dir.as_ref());
-            BuildStatus::Built { freeable_bytes }
+            match dir_size(build_dir.as_ref()) + dir_size(deps_dir.as_ref()) {
+                0 => BuildStatus::Clean,
+                freeable_bytes => BuildStatus::Built { freeable_bytes },
+            }
         } else {
             BuildStatus::Clean
         };
         Ok(status)
     }
+
+    fn project_name(&self) -> Option<anyhow::Result<String>> {
+        // mix.exs, which contains the project name, is not easy to parse without Elixir.
+        // While `mix run -e 'IO.puts(Mix.Project.config[:app])'` would work, it would
+        // also compile the application, which is of course an unintended side effect.
+        // To prevent false positives, we don't even try.
+        None
+    }
 }
 
 impl std::fmt::Display for Mix {
