@@ -11,9 +11,11 @@ use crate::{
     vcs::VersionControlSystem,
 };
 use anyhow::format_err;
-use camino::{Utf8Path, Utf8PathBuf};
 use chrono::{DateTime, Duration, Local, Utc};
-use std::fmt;
+use std::{
+    fmt,
+    path::{Path, PathBuf},
+};
 use tracing::{trace, warn};
 
 use self::mtime::dir_mtime;
@@ -27,7 +29,7 @@ pub struct Project {
     /// the enclosing folder.
     pub name: String,
     /// Where this project is located.
-    pub path: Utf8PathBuf,
+    pub path: PathBuf,
     /// The build tools used.
     pub build_tools: Vec<Box<dyn BuildTool>>,
     /// The VCS, if under version control.
@@ -38,15 +40,14 @@ pub struct Project {
 
 impl Project {
     pub fn from_dir(
-        path: &Utf8Path,
+        path: &Path,
         project_filter: &ProjectFilter,
-        vcs: Option<VersionControlSystem>,
         build_tool_manager: &BuildToolManager,
-    ) -> Option<Project> {
+    ) -> anyhow::Result<Option<Project>> {
         // Is this a project? => yes, if at least one build tool is recognized
         let build_tools = build_tool_manager.probe(path);
         if build_tools.is_empty() {
-            return None;
+            return Ok(None);
         }
 
         if let StatusFilter::ExceptClean = project_filter.status {
@@ -55,7 +56,7 @@ impl Project {
                 .iter()
                 .all(|tool| matches!(tool.status(), Ok(BuildStatus::Clean)))
             {
-                return None;
+                return Ok(None);
             }
         }
 
@@ -63,12 +64,12 @@ impl Project {
             Ok(name) => name,
             Err(e) => {
                 warn!("Failed to determine project name for {path:?}: {e}");
-                return None;
+                return Ok(None);
             }
         };
 
-        let mtime =
-            dir_mtime(path.as_std_path()).expect("BUG: build tool recognized but no files?!");
+        let mtime = dir_mtime(path)
+            .ok_or_else(|| format_err!("BUG: build tool recognized but no files?!"))?;
         let mtime: DateTime<Local> = mtime.into();
         let mtime: DateTime<Utc> = mtime.into();
 
@@ -79,16 +80,18 @@ impl Project {
                 min_stale=%project_filter.min_stale,
                 "Project skipped due to recent mtime",
             );
-            return None;
+            return Ok(None);
         }
 
-        Some(Project {
+        let vcs = VersionControlSystem::try_from(path)?;
+
+        Ok(Some(Project {
             name: project_name,
             path: path.to_owned(),
             build_tools,
             vcs,
             mtime,
-        })
+        }))
     }
 
     pub fn freeable_bytes(&self) -> u64 {
@@ -102,10 +105,7 @@ impl Project {
     }
 }
 
-fn project_name_from(
-    path: &Utf8Path,
-    build_tools: &[Box<dyn BuildTool>],
-) -> anyhow::Result<String> {
+fn project_name_from(path: &Path, build_tools: &[Box<dyn BuildTool>]) -> anyhow::Result<String> {
     for tool in build_tools {
         match tool.project_name() {
             Some(Ok(name)) => return Ok(name),
@@ -120,7 +120,7 @@ fn project_name_from(
             "Could not determine project name: Could not determine the directory name of {path:?}"
         )
     })?;
-    Ok(dirname.to_string())
+    Ok(dirname.as_os_str().to_string_lossy().to_string())
 }
 
 impl fmt::Display for Project {
@@ -137,7 +137,7 @@ impl fmt::Display for Project {
             .as_ref()
             .map(|x| format!("{x:?}"))
             .unwrap_or_else(|| "none".to_owned());
-        write!(f, "{} ({}; VCS: {})", path, tools, vcs)
+        write!(f, "{} ({}; VCS: {})", path.display(), tools, vcs)
     }
 }
 
